@@ -1971,9 +1971,11 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 			break;
 		}
 		optacc_a++;  
+		E_DEBUG("");
 		xformat_get_name(xformat, namebuf);
 		name = strob_str(namebuf);
 		parseret = swpath_parse_path(swpath, name);
+		E_DEBUG("");
 		if (parseret < 0) {
 			SWBIS_ERROR_IMPL();
 			return -55;
@@ -1993,11 +1995,13 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 		 */
 		current_path = swpath_get_pathname(swpath);
 		swlib_expand_escapes(NULL, NULL, current_path, current_path_expanded);
+		E_DEBUG("");
 
 		/* An entry in INFO for a archive member of "." has a path of "/" */
 		if (strcmp(strob_str(current_path_expanded), ".") == 0) {
 			strob_strcpy(current_path_expanded, "/");
 		}
+		E_DEBUG("");
 
 		/*
 		 * Sanitize and check the filename
@@ -2016,6 +2020,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 		swlib_squash_leading_dot_slash(strob_str(relocated_current_path));
 		l_current_path = strob_str(relocated_current_path);
 
+		E_DEBUG("");
 		if (optacc_a == 1) {
 			/*
 			 * Look for the current file at the
@@ -2043,6 +2048,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 		if (l_current_path && strlen(l_current_path)) {
 			E_DEBUG("HERE: Storage");
 			if (obj == (char*)NULL) {
+				E_DEBUG("");
 				obj = swheader_get_object_by_tag(infoheader, SW_OBJ_file, strob_str(current_path_expanded));
 			}
 
@@ -2064,6 +2070,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 				}
 			}
 
+			E_DEBUG("");
 			current_type = swheader_get_attribute(infoheader, SW_A_type, NULL);
 			current_type = swheaderline_get_value(current_type, NULL);
 
@@ -2102,7 +2109,9 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 			/*
 			 * translate the INFO file attributes to a file_hdr object.
 			 */
+			E_DEBUG("");
 			ahs_init_header(info_ahs2);
+			E_DEBUG("");
 			ret = swheader_fileobject2filehdr(infoheader, ahs_vfile_hdr(info_ahs2));
 			if (ret) {
 				/*
@@ -2174,6 +2183,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 			 * Compare the header stats from the storage section archive
 			 * member to the stats from the INFO file.
 			 */
+			E_DEBUG("");
 			if (sanity_compare(xformat_ahs_object(xformat), 
 					info_ahs2,
 					swpath_get_pathname(swpath), swi->verboseM >= SWC_VERBOSE_5)) {
@@ -2190,6 +2200,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 			 */				
 			ahs_copy(xformat_ahs_object(xformat), info_ahs2);
 
+			E_DEBUG("");
 			/*
 			 * Set the sanitized, relocated name.
 			 */
@@ -2245,6 +2256,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 				 * This code path is used in preview mode.
 				 */
 				xformat_set_ofd(xformat, fileset_fd);
+				E_DEBUG("");
 				header_ret = xformat_write_header(xformat);
 				xformat_set_ofd(xformat, vofd);
 			} else {
@@ -2261,9 +2273,11 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 			fileset_write_ret += header_ret;
 			
 			if (*current_type == SW_ITYPE_f) {
+				E_DEBUG("Entering xformat_copy_pass_md5");
 				ret = xformat_copy_pass_md5(xformat,
 						fileset_fd,
 						ifd, md5buf);
+				E_DEBUG("Finished xformat_copy_pass_md5");
 			} else {
 				ret = 0;
 			}
