@@ -283,46 +283,58 @@ critical_region_end(void)
 
 static
 int
-show_all_sw_selections(VPLOB * swspecs)
+show_all_sw_selections(VPLOB * swspecs, int fd)
 {
 	int i;
 	SWVERID * swverid;
 	STROB * tmp;
+	STROB * buf;
 	tmp = strob_open(1);
+	buf = strob_open(1);
 	i=0;
 	while ((swverid=vplob_val(swspecs, i++)) != NULL) {
-		fprintf(stderr, "%s\n", swverid_print(swverid, tmp));
+		swlib_writef(fd, buf, "%s\n", swverid_print(swverid, tmp));
 	}
 	strob_close(tmp);
-	return 0;
+	strob_close(buf);
+	return i-1;
 }
 
 static
 void
 set_pgm_mode(GB * G, BLIST * BL, char * pgm_mode, char * one_liner, int opt_index_file_format)
 {
-	if (opt_index_file_format) {
+	E_DEBUG2("pgm_mode is %s", pgm_mode);
+	E_DEBUG2("one_liner is %s", one_liner);
+	E_DEBUG2("opt_index_file_format is %d", opt_index_file_format);
+	if (
+		opt_index_file_format
+	) {
 		strcpy(pgm_mode, SWLIST_PMODE_INDEX);
+		E_DEBUG2("pgm_mode is %s\n", pgm_mode);
 		return;
 	}
 	if (BL->catalogM != NULL) {
 		strcpy(pgm_mode, SWLIST_PMODE_CAT);
+		E_DEBUG2("pgm_mode is %s\n", pgm_mode);
 		return;
 	}
 
 	if (strlen(pgm_mode) > 0) {
 		/* already set by option */
+		E_DEBUG2("pgm_mode is [already] %s\n", pgm_mode);
 		return;
 	}
-	if (strstr(one_liner, "product")) {
+	if (strstr(one_liner, SWLIST_PMODE_PROD)) {
 		strcpy(pgm_mode, SWLIST_PMODE_PROD);
-	} else if (strstr(one_liner, "file")) {
+	} else if (strstr(one_liner, SWLIST_PMODE_FILE)) {
 		strcpy(pgm_mode, SWLIST_PMODE_FILE);
-	} else if (strstr(one_liner, "dir")) {
+	} else if (strstr(one_liner, SWLIST_PMODE_DIR)) {
 		strcpy(pgm_mode, SWLIST_PMODE_DIR);
 	} else {
 		strcpy(pgm_mode, SWLIST_PMODE_PROD);
 	}
+	E_DEBUG2("pgm_mode is %s", pgm_mode);
 }
 
 static
@@ -341,7 +353,6 @@ is_index_file_format(char * pgm_mode, int opt_alt_verbose, int explicitly_set)
 	if (
 		(
 		strcmp(pgm_mode, SWLIST_PMODE_PROD) == 0 ||
-		/* strcmp(pgm_mode, SWLIST_PMODE_ATT) == 0 || */
 		strcmp(pgm_mode, SWLIST_PMODE_DIR) == 0 ||
 		strcmp(pgm_mode, SWLIST_PMODE_FILE) == 0 ||
 		strcmp(pgm_mode, SWLIST_PMODE_CAT) == 0 ||
@@ -354,6 +365,7 @@ is_index_file_format(char * pgm_mode, int opt_alt_verbose, int explicitly_set)
 		return 0;
 	} else {
 		if (opt_alt_verbose)
+			/* means INDEX file format */	
 			return 1;
 		else
 			return 0;
@@ -686,7 +698,8 @@ main(int argc, char **argv)
 	int local_stdout_in_use = 0;
 	int reqs_failed = 0;
 	int nmatches;
-	int local_attr_mode;
+	int uts_attr_mode;
+	int num_cmd_line_swspecs;
 	struct extendedOptions * opta = optionsArray;
 	struct termios	*login_orig_termiosP = NULL;
 	struct winsize	*login_sizeP = NULL;
@@ -714,6 +727,7 @@ main(int argc, char **argv)
 	char cwd[1024];
 	char * remote_shell_command = REMOTE_SSH_BIN;
 	char * remote_shell_path;
+	char * current_opt_level = NULL;
 
 	STRAR * target_cmdlist;
 	STRAR * target_tramp_list;
@@ -987,7 +1001,7 @@ main(int argc, char **argv)
 	eopt_distribution_target_directory = "/";
 	eopt_installed_software_catalog = "var/lib/swbis/catalog/";
 
-	eopt_one_liner			= "products"; 
+	eopt_one_liner			= SWLIST_PMODE_PROD; 
 	eopt_select_local		= CHARFALSE;
 	eopt_verbose			= "1";
 	wopt_no_getconf			= "true";
@@ -1043,11 +1057,15 @@ main(int argc, char **argv)
 		case 'a':
 			if (swuts_is_uts_attribute(optarg)) {
 				BL->has_uts_attributesM++;
+				strcpy(wopt_pgm_mode, SWLIST_PMODE_UTS_ATT);
+			} else if (swlist_is_annex_attribute(optarg)) {
+				BL->has_annex_attributesM++;
+				strcpy(wopt_pgm_mode, SWLIST_PMODE_ATT);
 			} else {
 				BL->has_soc_attributesM++;
 				strcpy(wopt_pgm_mode, SWLIST_PMODE_ATT);
 			}
-			swlist_blist_attr_add(BL, optarg);
+			swlist_blist_attr_add(BL, current_opt_level, optarg);
 			break;
 		case 'c':
 			opt_catalog_dest_dir = strdup(optarg);
@@ -1062,6 +1080,8 @@ main(int argc, char **argv)
 			break;
 		case 'l':
 			opt_level_is_set = 1;
+			if (current_opt_level) free(current_opt_level);
+			current_opt_level = strdup(optarg);
 			if (process_level_option(BL, optarg)) {
 				/* error */
 				sw_e_msg(G, "invalid level: %s \n", optarg);
@@ -1693,18 +1713,28 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 		LCEXIT(sw_exitval(G, target_loop_count, target_success_count));
 	}
 
+	num_cmd_line_swspecs = show_all_sw_selections(swspecs, nullfd);
+
+
+	/* ----------------------------- */
+	/* ----------------------------- */
 	/* Loop over the targets.  */
+	/* ----------------------------- */
+	/* ----------------------------- */
 
    	current_arg = swc_get_next_target(argv, argc, &optind, 
 						G->g_targetfd_array, 
 					eopt_distribution_target_directory,
 						&num_remains);
-E_DEBUG3("current_arg=[%s] eopt_distribution_target_directory=[%s]", current_arg, eopt_distribution_target_directory);
-
+	E_DEBUG3("current_arg=[%s] eopt_distribution_target_directory=[%s]", current_arg, eopt_distribution_target_directory);
+	E_DEBUG2("num_cmd_line_swspecs is %d", num_cmd_line_swspecs);
 	E_DEBUG("");
+
 	while (current_arg && local_stdin == 0) {
-E_DEBUG2("current_arg=[%s]", current_arg);
-E_DEBUG2("Lowest fd is now [%d]", swgp_find_lowest_fd(0));
+
+		E_DEBUG2("current_arg=[%s]", current_arg);
+		E_DEBUG2("Lowest fd is now [%d]", swgp_find_lowest_fd(0));
+
 		distdataO = swi_distdata_create();
 		swgp_signal(SIGINT, safe_sig_handler);
 		swgp_signal(SIGPIPE, safe_sig_handler);
@@ -1819,8 +1849,8 @@ E_DEBUG2("Lowest fd is now [%d]", swgp_find_lowest_fd(0));
 		E_DEBUG2("target_path is [%s]", target_path);
 		
 		/* More policy and sanity checks */
-		apply_usage_restrictions(NULL, G, target_path);
 
+		apply_usage_restrictions(NULL, G, target_path);
 
 		if (strcmp(target_path, "-") == 0 && target_nhops >= 1) {
 			/* error cannot write to stdout except on localhost */
@@ -1840,6 +1870,7 @@ E_DEBUG2("Lowest fd is now [%d]", swgp_find_lowest_fd(0));
 		}
 
 		/* Policy and sanity checks for use of standard output */
+
 		local_stdout_in_use = 1;
 		if (
 			BL->index_format_is_setM == 1 ||
@@ -1849,6 +1880,7 @@ E_DEBUG2("Lowest fd is now [%d]", swgp_find_lowest_fd(0));
 		}
 		
 		 /* Set the informational Event messages fd */
+
 		if (local_stdout_in_use) {
 			swevent_fd = STDERR_FILENO; 
 		} else {
@@ -1898,6 +1930,7 @@ E_DEBUG2("Lowest fd is now [%d]", swgp_find_lowest_fd(0));
 
 		/* Set the current target_path into the task script
 		   protocol object */
+
 		swicol_set_targetpath(swicol, target_path);
 		swicol_set_task_debug(swicol, G->g_do_task_shell_debug);
 
@@ -1958,7 +1991,9 @@ E_DEBUG2("Lowest fd is now [%d]", swgp_find_lowest_fd(0));
 					sw_e_msg(G, "lseek internal error on stdio_fdar[0]\n");
 					f_retval = 1;
 					/* goto next target, this one failed */
+					E_DEBUG("goto TARGET1");
 					goto TARGET1;
+					E_DEBUG("goto ENTER_WITH_FAILURE");
 					goto ENTER_WITH_FAILURE;
 				}
 			} 
@@ -2014,6 +2049,7 @@ E_DEBUG2("Lowest fd is now [%d]", swgp_find_lowest_fd(0));
 		/* if local_stdin == 1, then this routine returns 0 doing nothing */
 
 		/* G->g_gpuflag1 conveys the mode into the target script */
+
 		strncpy(G->g_gpufieldM, wopt_pgm_mode, sizeof(G->g_gpufieldM));
 		E_DEBUG("");
 		source_write_pid = swc_run_source_script(G,
@@ -2093,6 +2129,7 @@ E_DEBUG2("Lowest fd is now [%d]", swgp_find_lowest_fd(0));
 			ret = swc_read_target_message_129(G, target_fdar[0], target_current_dir, G->g_verboseG, "target pwd");
 			if (ret < 0) {
 				/* FIXME, should be bigger error than this */
+				E_DEBUG("goto ENTER_WITH_FAILURE");
 				sw_e_msg(G, "SW_INTERNAL_ERROR for target %s in file %s at line %d: message _129 failed\n",
 						current_arg, __FILE__, __LINE__);
 				goto ENTER_WITH_FAILURE;
@@ -2187,6 +2224,7 @@ E_DEBUG2("Lowest fd is now [%d]", swgp_find_lowest_fd(0));
 					" (loc=target_access)\n");
 				
 				/* Go to the next target */
+				E_DEBUG("goto ENTER_WITH_FAILURE");
 				goto ENTER_WITH_FAILURE;
 			}
 
@@ -2204,6 +2242,7 @@ E_DEBUG2("Lowest fd is now [%d]", swgp_find_lowest_fd(0));
 					strob_str(target_access_message));
 
 				/* Go to the next target */
+				E_DEBUG("goto ENTER_WITH_FAILURE");
 				goto ENTER_WITH_FAILURE;
 			}
 			E_DEBUG("");
@@ -2260,7 +2299,7 @@ E_DEBUG2("Lowest fd is now [%d]", swgp_find_lowest_fd(0));
 				 */
 				xx_swi = swlist_list_create_swi(G, opta, swspecs, target_path);
 				xx_specs = swpl_get_dependency_specs(G, xx_swi, SW_A_prerequisites, 0, 0);
-				show_all_sw_selections(xx_specs);
+				show_all_sw_selections(xx_specs, 2);
 			} else {
 				E_DEBUG("");
 				apply_usage_restrictions("archive", G, "");
@@ -2306,7 +2345,7 @@ E_DEBUG2("Lowest fd is now [%d]", swgp_find_lowest_fd(0));
 			   This task script will get the catalog according to the
 			   software selections */
 
-			/** DEBUG: show_all_sw_selections(swspecs); */
+			/** DEBUG: show_all_sw_selections(swspecs, 2); */
 			E_DEBUG("");
 			apply_usage_restrictions("dir", G, "");
 
@@ -2328,15 +2367,24 @@ E_DEBUG2("Lowest fd is now [%d]", swgp_find_lowest_fd(0));
 			ret = swpl_send_success(swicol, target_fdar[1], G->g_swi_event_fd,
 						SWBIS_TS_Do_nothing ": testing 123");
 
-			local_attr_mode = (
-				BL->has_uts_attributesM &&
-				BL->level_is_setM == 0  /* i.e. a host level only */
-					);
-			if (
-				local_attr_mode
-			) {
-				/* The -a <attribute> option was used without a -l level specification */
+			uts_attr_mode = (
+				num_cmd_line_swspecs == 0 &&
+				BL->has_soc_attributesM == 0 &&
+				BL->has_annex_attributesM == 0 &&
+				BL->has_uts_attributesM > 0 &&
+				BL->level_is_setM == 0  /* i.e. a level not given on cmd line */
+			);
+
+			E_DEBUG2("uts_attr_mode is %d", uts_attr_mode);
+
+			if ( uts_attr_mode) {
+
+				/* This is the special mode that displays the UTS attributes
+				   of the host machine instead of the attributes from the package.
+				   This is an implementation extension. */
+
 				attr_index = 0;
+				E_DEBUG("ELSE LADDER");
 				E_DEBUG("at while");
 				while ((attr=swlist_blist_get_next_attr(BL, attr_index, &attr_index)) != NULL) {
 					/* attr = strar_get(BL->attributesM, 0); */
@@ -2346,13 +2394,6 @@ E_DEBUG2("Lowest fd is now [%d]", swgp_find_lowest_fd(0));
 						E_DEBUG("");
 						/* write the config.guess'ed triplet to stdout,
 						   it should be sitting in uts->arch_tripletM */
-						/*
-						attr = uts->arch_tripletM ? uts->arch_tripletM : "unknown";
-						if (opt_index_file_format == 0)
-							fprintf(stdout, "%s\n", attr);
-						else
-							fprintf(stdout, "    " SW_A_architecture " %s\n", attr);
-						*/	
 						swlist_write_attr2(BL, cl_target_target, SW_A_architecture, uts->arch_tripletM, attr_index);
 					} 
 	
@@ -2374,19 +2415,27 @@ E_DEBUG2("Lowest fd is now [%d]", swgp_find_lowest_fd(0));
 					attr_index++;
 				}
 
-				/* The required fulfillment of SWBIS_TS_Get_iscs_listing is below
-				   in the default else block of the next statement */
-				E_DEBUG("");
-			} 
 
-			if (swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_CAT) == 0) {
+				ret = swpl_send_success(swicol, target_fdar[1], G->g_swi_event_fd,
+					SWBIS_TS_Get_iscs_listing ": not needed");
+				if (ret != 0) {
+					swicol_set_master_alarm(swicol);
+					sw_e_msg(G, "swicol: fatal: %s:%d\n", __FILE__, __LINE__);
+				}
+
+				E_DEBUG("");
+
+			} else if (swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_CAT) == 0) {
+
 				/* This is the code path for the -c DIR option.
 				   Write a tar archive of the catalog to stdout */
 
+				E_DEBUG("ELSE LADDER");
+				E_DEBUG("swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_CAT) == 0");
+
 				swc_check_for_current_signals(G, __LINE__, wopt_no_remote_kill);
 
 				swicat_write_isc_script(isc_script_buf, G, swspecs, NULL, NULL, NULL, SWICAT_FORM_TAR1);
-				/* swicol_set_task_idstring(swicol, SWBIS_TS_Get_iscs_listing); */
 				ret = swicol_rpsh_task_send_script2(swicol,
 					target_fdar[1],			/* file descriptor of the task shell's stdin */
 					512,				/* data size, here just a gratuitous block of NULs */
@@ -2431,26 +2480,16 @@ E_DEBUG2("Lowest fd is now [%d]", swgp_find_lowest_fd(0));
 				E_DEBUG("done");
 
 			} else if (
-				swlist_has_annex_attribute(BL) ||
+				BL->has_soc_attributesM > 0 ||
+				BL->has_annex_attributesM > 0 ||
 				swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_FILE) == 0 ||
+				swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_ATT) == 0 ||
 				swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_INDEX) == 0
 			) {
-
-				/* This section will list the files in installed software */	
-
-				/* Sample abort code (for reference)
-				sw_e_msg(G, "file listing for installed software not yet implemented\n");
-				swicol_set_master_alarm(swicol);
-				swicol_set_task_idstring(swicol, SWBIS_TS_Get_iscs_listing);
-				abort_script(swicol, G, target_fdar[1]);
-				ret = swpl_send_abort(swicol, target_fdar[1], G->g_swi_event_fd, "");
-				*/
-
-				/*
-				 * ===========================================================
-				 * ===========================================================
-				 */
+				E_DEBUG("ELSE LADDER");
+				E_DEBUG2("wopt_pgm_mode is [%s]", wopt_pgm_mode);
 				E_DEBUG("SWLIST_PMODE_FILE");
+				/* This section will list the files in installed software */	
 
 				if (! does_have_sw_selections(swspecs)) {
 					E_DEBUG("No selections given on command line");
@@ -2501,12 +2540,14 @@ E_DEBUG2("Lowest fd is now [%d]", swgp_find_lowest_fd(0));
 					swicol_show_events_to_fd(swicol, STDERR_FILENO, -1);
 
 
+				/* ----------------------------------------*/	
+				/* ----------------------------------------*/	
 				/*
-				 * --------------------------------------------
 				 * Now loop over the selections
-				 * --------------------------------------------
 				 */
-	
+				/* ----------------------------------------*/	
+				/* ----------------------------------------*/	
+			
 				E_DEBUG("Looping over selections");
 				G->in_shls_looperM = 1;
 				ism = 0;
@@ -2537,8 +2578,12 @@ E_DEBUG2("Lowest fd is now [%d]", swgp_find_lowest_fd(0));
 						s_retval++;
 						continue;
 					} 
-	
-					/* Loop over the responses to a query */
+
+					/* ----------------------------------------*/	
+					/* ----------------------------------------*/	
+					/* Loop over the responses to a selection query */
+					/* ----------------------------------------*/	
+					/* ----------------------------------------*/	
 	
 					while(
 						f_retval == 0 &&
@@ -2574,9 +2619,13 @@ E_DEBUG2("Lowest fd is now [%d]", swgp_find_lowest_fd(0));
 						if (rp_status != 0) {
 							/* error, but continuation possible */
 							E_DEBUG("");
-							if (rp_status != SWVERIFY_RP_STATUS_NO_INTEGRITY)
+							if (
+								rp_status != SWP_RP_STATUS_NO_INTEGRITY &&
+								rp_status != SWP_RP_STATUS_NO_LOCK
+							) {
 								sw_e_msg(G, "SW_INTERNAL_ERROR: %s:%d rp_status=%d\n",
 									__FILE__, __LINE__, rp_status);
+							}
 							s_retval++;
 							}
 						E_DEBUG2("signal_flag=%d", G->g_signal_flag);
@@ -2611,37 +2660,37 @@ E_DEBUG2("Lowest fd is now [%d]", swgp_find_lowest_fd(0));
 	
 				if (ret != 0) {
 					abort_script(swicol, G, target_fdar[1]);
-       	 			swpl_send_abort(swicol, target_fdar[1], G->g_swi_event_fd, "");
+       	 				swpl_send_abort(swicol, target_fdar[1], G->g_swi_event_fd, "");
 					f_retval++;
 				}
+
 				swc_check_for_current_signals(G, __LINE__, wopt_no_remote_kill);
 				ret = 0;
-				if (f_retval == 0)
+
+				if (f_retval == 0) {
 					ret = swpl_send_success(swicol, target_fdar[1], G->g_swi_event_fd,
 							SWBIS_TS_Do_nothing ": testing 89");
+				}
+
 				if (ret != 0) {
 					abort_script(swicol, G, target_fdar[1]);
        		 			swpl_send_abort(swicol, target_fdar[1], G->g_swi_event_fd, "");
 					f_retval++;
 				}
 
-				if (s_retval)
+				if (s_retval) {
 					f_retval ++;
+				}
 
-				/*
-				 * ===========================================================
-				 * ===========================================================
-				 * ===========================================================
-				 * ===========================================================
-				 */
-
-				if (sl)
+				if (sl) {
 					swicat_sl_delete(sl);
+				}
 			} else if (
 				swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_PROD) == 0 ||
 				swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_DIR) == 0 ||
 				swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_DEP1) == 0 
 			) {
+				E_DEBUG("ELSE LADDER");
 				E_DEBUG("SWLIST_PMODE_PROD SWLIST_PMODE_DIR SWLIST_PMODE_DEP1");
 				ret = swpl_do_list_catalog_entries2(G,
 						swspecs, pre_reqs, NULL, ex_reqs,
@@ -2660,21 +2709,13 @@ E_DEBUG2("Lowest fd is now [%d]", swgp_find_lowest_fd(0));
 					reqs_failed = 0;
 				}
 			} else {
-				if (local_attr_mode) {
-					ret = swpl_send_success(swicol, target_fdar[1], G->g_swi_event_fd,
-						SWBIS_TS_Get_iscs_listing ": not needed");
-					if (ret != 0) {
-						swicol_set_master_alarm(swicol);
-						sw_e_msg(G, "swicol: fatal: %s:%d\n", __FILE__, __LINE__);
-					}
-				} else {
-					E_DEBUG("");
-					sw_e_msg(G, "unsupported mode\n");
-					swicol_set_master_alarm(swicol);
-					swicol_set_task_idstring(swicol, SWBIS_TS_Get_iscs_listing);
-					abort_script(swicol, G, target_fdar[1]);
-					ret = swpl_send_abort(swicol, target_fdar[1], G->g_swi_event_fd, "");
-				}
+				E_DEBUG("ELSE LADDER DEFAULT");
+				E_DEBUG("");
+				sw_e_msg(G, "unsupported mode\n");
+				swicol_set_master_alarm(swicol);
+				swicol_set_task_idstring(swicol, SWBIS_TS_Get_iscs_listing);
+				abort_script(swicol, G, target_fdar[1]);
+				ret = swpl_send_abort(swicol, target_fdar[1], G->g_swi_event_fd, "");
 			}
 			if (G->g_do_debug_events)
 				swicol_show_events_to_fd(swicol, STDERR_FILENO, -1);
@@ -2703,7 +2744,7 @@ E_DEBUG2("Lowest fd is now [%d]", swgp_find_lowest_fd(0));
 				/* Scratch test area, access with the --test1 option */
 				xx_swi = swlist_list_create_swi(G, opta, swspecs, target_path);
 				xx_specs = swpl_get_dependency_specs(G, xx_swi, SW_A_prerequisites, 0, 0);
-				show_all_sw_selections(xx_specs);
+				show_all_sw_selections(xx_specs, 2);
 			} else {
 				E_DEBUG("");
 				ret = swlist_list_distribution_archive(G,
