@@ -51,19 +51,6 @@
 #include "shlib.h"
 #include "ls_list.h"
 
-int
-is_annex_attribute(char * name)
-{
-	if (
-		strcmp(name, SW_A_mod_date) &&
-		strcmp(name, SW_A_create_date) &&
-		strcmp(name, SW_A_software_spec)
-	)
-		return 0;
-	else
-		return 1;
-}
-
 static
 void
 looper_abort(GB * G, SWICOL * swicol, int ofd)
@@ -476,6 +463,20 @@ write_annex_attributes (GB * G, SWICAT_E * e, BLIST * BL, char * cl_target_targe
 	return 0;
 }
 
+int
+swlist_is_annex_attribute(char * name)
+{
+	if (
+		strcmp(name, SW_A_mod_date) &&
+		strcmp(name, SW_A_create_date) &&
+		strcmp(name, SW_A_software_spec)
+	)
+		return 0;
+	else
+		return 1;
+}
+
+
 void
 swlist_write_attr2(BLIST * BL, char * host, char * name, char * value, int attr_index)
 {
@@ -944,7 +945,7 @@ swlist_has_annex_attribute(BLIST * BL)
 	E_DEBUG("");
 	attr_index = 0;
 	while ((attr=swlist_blist_get_next_attr(BL, attr_index, &attr_index)) != NULL) {
-		if (is_annex_attribute(attr)) {
+		if (swlist_is_annex_attribute(attr)) {
 			E_DEBUG("returning 1");
 			return 1;
 		}
@@ -1137,6 +1138,7 @@ extern struct blist_level *  blist_levels_i;
 void
 blist_init(BLIST * blist)
 {
+	blist->attr_levelsM = strar_open();
 	blist->attributesM = strar_open();
 	blist->attr_flagsM = strob_open(12);
 	blist->do_get_create_dateM = 0;
@@ -1148,6 +1150,7 @@ blist_init(BLIST * blist)
 	blist->level_is_setM = 0;
 	blist->has_soc_attributesM = 0;
 	blist->has_uts_attributesM = 0;
+	blist->has_annex_attributesM = 0;
 	blist->isf_headerM = NULL;
 }
 
@@ -1208,6 +1211,7 @@ swlist_looper_sr_payload(GB * G, BLIST * BL, char * target_path, char * cl_targe
 	swicat_sr_form_swspec(sr, swspec_string);
 
 	E_DEBUG("");
+	E_DEBUG2("wopt_pgm_mode is %s", wopt_pgm_mode);
 	*p_rp_status = 0;
 	E_DEBUG("setting *p_rp_status = 0");
 	if (strlen(catalog_entry_directory) == 0) {
@@ -1273,8 +1277,8 @@ swlist_looper_sr_payload(GB * G, BLIST * BL, char * target_path, char * cl_targe
 		E_DEBUG2("error ret=%d", ret);
 		sw_e_msg(G, "swpl_session_lock lock failed for %s, ret=%d\n", strob_str(btmp), ret);
 		/* sw_d_msg(G, "swpl_session_lock lock failed for %s, ret=%d\n", strob_str(btmp), ret); */
+		/* *p_rp_status = SWP_RP_STATUS_NO_LOCK; */
 		*p_rp_status = 1;
-		E_DEBUG("setting *p_rp_status = 1");
 		return 1;
 	} 
 
@@ -1596,10 +1600,12 @@ swlist_looper_sr_payload(GB * G, BLIST * BL, char * target_path, char * cl_targe
 	}
 	E_DEBUG("");
 	E_DEBUG2("LOWEST FD=%d", show_nopen());
+	E_DEBUG2("wopt_pgm_mode is %s", wopt_pgm_mode);
 
 	if (
 		swlist_has_annex_attribute(BL) && /* has create_date create_time or software_spec */
-		swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_INDEX) != 0 /* not index mode */
+		BL->index_format_is_setM == 0
+		/* swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_INDEX) != 0 */
 	) {
 		/* annex attributes and not '-v' mode */
 		write_annex_attributes (G, ee, BL, cl_target_target, sr);
@@ -1633,10 +1639,12 @@ swlist_looper_sr_payload(GB * G, BLIST * BL, char * target_path, char * cl_targe
 				E_DEBUG("skipping listing files from installed catalog");
 			}
 		}
+	} else if (swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_ATT) == 0) {
+		sw_e_msg(G, "listing attributes not supported yet\n");
 	} else {
 		/* program internal errro */
 		/* never happens */
-		SWLIB_FATAL("");
+		sw_e_msg(G, "unhandled mode in swlist_lib.c\n");
 	}
 
 	E_DEBUG2("LOWEST FD=%d", show_nopen());
@@ -1708,10 +1716,14 @@ swlist_looper_sr_payload(GB * G, BLIST * BL, char * target_path, char * cl_targe
 }
 
 void
-swlist_blist_attr_add(BLIST * BL, char * attr)
+swlist_blist_attr_add(BLIST * BL, char * level, char * attr)
 {
 	int n;
 	n = strar_num_elements(BL->attributesM);
+	if (!level)
+		strar_add(BL->attr_levelsM, SW_A_host);
+	else
+		strar_add(BL->attr_levelsM, level);
 	strar_add(BL->attributesM, attr);
 	strob_chr_index(BL->attr_flagsM, n, '\x00');
 }
