@@ -1,6 +1,6 @@
 /*  swremove.c -- The swbis package removal utility.
 
- Copyright (C) 2007 Jim Lowe
+ Copyright (C) 2007,2010 Jim Lowe
  All Rights Reserved.
   
  COPYING TERMS AND CONDITIONS:
@@ -564,6 +564,7 @@ main(int argc, char **argv)
 	VPLOB * ex_reqs;
 	STROB * btmp;
 	STROB * btmp2;
+	STROB * target_current_dir;
 	STROB * target_control_message;
 	STROB * target_start_message;
 	STROB * target_catalog_message;
@@ -802,6 +803,7 @@ main(int argc, char **argv)
 	source_line_buf = strob_open(10);
 	target_line_buf = strob_open(10);
 	target_catalog_dir = strob_open(10);
+	target_current_dir = strob_open(10);
 
 	nullfd = G->g_nullfd;
 
@@ -1340,10 +1342,10 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 	/* Show the options to stdout.  */
 
 	if (swc_is_option_true(wopt_show_options_files)) { 
-		parse_options_files(opta, 
+		swextopt_parse_options_files(opta, 
 			system_defaults_files, 
 			progName, 1 /* not req'd */,  1 /* show_only */);
-		parse_options_files(opta, 
+		swextopt_parse_options_files(opta, 
 			opt_option_files, 
 			progName,
 		 	1 /* not req'd */,  1 /* show_only */);
@@ -1358,7 +1360,7 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 	 */
 
 	if (wopt_no_defaults == 0) {
-		optret += parse_options_files(opta, 
+		optret += swextopt_parse_options_files(opta, 
 			system_defaults_files, 
 			progName, 
 			0 /* not req'd */,  0 /* not show_only */);
@@ -1374,7 +1376,7 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 	 * = = = = = = = = = = = = = = = = = = = = = = = = = = = = = 
 	 */
 
-	optret += parse_options_files(opta, 
+	optret += swextopt_parse_options_files(opta, 
 		opt_option_files, 
 		progName, 	
 		1 /* req'd */, 0 /* not show_only */);
@@ -1595,6 +1597,7 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 		new_cl_target_target = swc_convert_multi_host_target_syntax(G, cl_target_target);
 		free(cl_target_target);
 		cl_target_target = new_cl_target_target;
+		G->g_cl_target_targetM = strdup(cl_target_target);
 
 		/* Parse the target string and set the commands to invoke */
 
@@ -1913,7 +1916,36 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 			}
 
 			sw_d_msg(G, "start_ctl_message(loc=start): %s\n", strob_str(target_start_message));
+
+			/*
+			 * ===============================
+			 * read the pwd current directory message
+			 * from the target
+			 * MSG_129 
+			 * ===============================
+			 */
+
+			ret = swc_read_target_message_129(G, target_fdar[0], target_current_dir, G->g_verboseG, "target pwd");
+			if (ret < 0) {
+				sw_e_msg(G, "SW_INTERNAL_ERROR for target %s in file %s at line %d: message _129 failed\n",
+						current_arg, __FILE__, __LINE__);
+				goto ENTER_WITH_FAILURE;
+			}
+
+			/* Now adjust the target_path to be an absolute path
+			   if it is not already */
+
+			if (*target_path != '/') {
+				target_path = swc_make_absolute_path(strob_str(target_current_dir), target_path);
+				swicol_set_targetpath(swicol, target_path);
+			}
 			
+			if (swlib_is_sh_tainted_string(target_path)) {
+				SWLIB_FATAL("tainted path");
+			}
+
+			/* Now target_path is absolute */
+
 			if (target_nhops >= wopt_kill_hop_threshhold) {
 
 				/* Construct the remote kill vector if warranted  */
