@@ -1,6 +1,6 @@
 /* swremove_lib.c -- swremove routines.
 
- Copyright (C) 2007 James H. Lowe, Jr. 
+ Copyright (C) 2007,2010 James H. Lowe, Jr. 
  All Rights Reserved.
  
  COPYING TERMS AND CONDITIONS:
@@ -60,7 +60,6 @@ int
 make_remove_glob_list_for(int do_dir, GB * G, SWI * swi, STROB * buf, SWI_FILELIST * fl, int do_remove_volatile, int do_rename_volatile)
 {
 	STROB * rm_tmp;
-	STROB * suffix_tmp;
 	char * sx;
 	int type;
 	int ix;
@@ -176,13 +175,9 @@ make_remove_command_script_fragment(GB * G, CISF_PRODUCT * cisf, SWI * swi, STRO
 	STROB * suffix_tmp;
 	STROB * rm_tmp;
 	STROB * rmdir_tmp;
-	char * record;
-	char * sx;
-	int ix;
 	char * remove_volatile;	
 	int do_remove_volatile;
 	int do_rename_volatile;
-	int action;
 
 	/* Tag every file in a volatile directory as being volatile itself
 	   FIXME ??? is this the correct thing to do */
@@ -249,7 +244,7 @@ make_remove_command_script_fragment(GB * G, CISF_PRODUCT * cisf, SWI * swi, STRO
 
 static
 int
-remove_files(GB * G, CISF_PRODUCT * cisf, SWI * swi, SWICOL * swicol, SWICAT_E * e, SWI_FILELIST * file_list, int ofd)
+remove_files(GB * G, char * target_path, CISF_PRODUCT * cisf, SWI * swi, SWICOL * swicol, SWICAT_E * e, SWI_FILELIST * file_list, int ofd)
 {
 	STROB * buf;
 	int ret;
@@ -272,7 +267,7 @@ remove_files(GB * G, CISF_PRODUCT * cisf, SWI * swi, SWICOL * swicol, SWICAT_E *
 		swicol,
 		ofd,
 		512,
-		".",
+		target_path,  /* WAS "."*/
 		strob_str(buf),
 		SWBIS_TS_remove_files);
 	if (ret != 0) {
@@ -386,7 +381,6 @@ swremove_write_source_copy_script2(GB * G,
 
 {
 	int ret;
-	char * isc_relpath;
 	char * dirname;
 	char * basename;
 	char * pax_write_command;
@@ -542,13 +536,16 @@ swremove_write_source_copy_script2(GB * G,
 
 	/* Now here is the script */
 	strob_sprintf(buffer_new, STROB_DO_APPEND,
+		"IFS=\"`printf ' \\t\\n'`\"\n"
 		"trap '/bin/rm -f ${LOCKPATH}.lock; exit 1' 1 2 15\n"
 		"echo " SWBIS_TARGET_CTL_MSG_125 ": " KILL_PID "\n"
+		"echo " SWBIS_TARGET_CTL_MSG_129 ": \"`pwd | head -1`\"\n"
 		CSHID
 		"export LOCKENTRY\n"
 		"LOCKPATH=\"\"\n"
 		"%s\n"  			/* SEVENT: SW_SESSION_BEGINS */
 		"%s" 				/* swicol_subshell_marks */
+		"wcwd=\"`pwd`\"\n"
 		"export lock_did_lock\n"
 		"export opt_force_lock\n"
 		"export swbis_ignore_scripts\n"
@@ -572,6 +569,7 @@ swremove_write_source_copy_script2(GB * G,
 		"%s\n"			/* lf_ lock routine */
 		"%s\n"			/* shls__cleansh routine */
 		"%s\n"			/* shls_cleansh routine */
+		"%s\n"			/* shls_make_dir_absolute */
 		"%s" 			/* set statement for verbosity */
 		"export opt_to_stdout\n"
 		"opt_to_stdout=\"\"\n"
@@ -589,6 +587,43 @@ swremove_write_source_copy_script2(GB * G,
 		"debug_task_shell=\"%s\"\n"
 		"swexec_status=0\n"
 		"export LOCKPATH\n"
+
+		"#\n"
+		"# make targetpath absolute\n"
+		"#\n"
+		"case \"$targetpath\" in\n"
+		"/*)\n"
+		";;\n"
+		"*)\n"
+		"mda_pwd=\"$wcwd\"\n"
+		"mda_target_path=\"$targetpath\"\n"
+		"shls_make_dir_absolute\n"
+		"targetpath=\"$mda_target_path\"\n"
+		"# targetpath is now absolute\n"
+		";;\n"
+		"esac\n"
+		"#\n"
+		"# END of code to make absolute\n"
+		"#\n"
+
+		"#\n"
+		"# make dirname absolute\n"
+		"#\n"
+		"case \"$dirname\" in\n"
+		"/*)\n"
+		";;\n"
+		"*)\n"
+		"mda_pwd=\"$wcwd\"\n"
+		"mda_target_path=\"$dirname\"\n"
+		"shls_make_dir_absolute\n"
+		"dirname=\"$mda_target_path\"\n"
+		"# dirname is now absolute\n"
+		";;\n"
+		"esac\n"
+		"#\n"
+		"# END of code to make dirname absolute\n"
+		"#\n"
+
 		"# Here is the override of the shls_looper_payload function\n"
 		"#\n"
 		"%s\n"    /* <<<--- shls_looper_payload looper_routine */
@@ -737,6 +772,7 @@ swremove_write_source_copy_script2(GB * G,
 /*_% */	shlib_get_function_text_by_name("lf_remove_lock", shell_lib_buf, NULL),
 /*_% */	shlib_get_function_text_by_name("shls__cleansh", shell_lib_buf, NULL),
 /*_% */	shlib_get_function_text_by_name("shls_cleansh", shell_lib_buf, NULL),
+/*_% */	shlib_get_function_text_by_name("shls_make_dir_absolute", shell_lib_buf, NULL),
 /*_% */		strob_str(set_vx),
 /*_% */		blocksize,
 /*_% */		dirname,
@@ -802,7 +838,6 @@ int
 swremove_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 		SWICAT_SR * sr, int ofd, int ifd, int * p_rp_status, SWUTS * uts)
 {
-	int i;
 	int retval;
 	int rstatus;
 	int ret;
@@ -812,10 +847,8 @@ swremove_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 	int do_enforce_scripts;
 	char * pax_read_command;
 	char * epath;
-	char * name;
 	char * installed_software_catalog;
 	char * catalog_entry_directory;
-	struct stat st;
 	STROB * btmp;
 	STROB * btmp2;
 	STROB * swspec_string;
@@ -1208,7 +1241,7 @@ swremove_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 		}
 	} else {
 		E_DEBUG("remove files");
-		ret = remove_files(G, cisf, swi, swicol, e, file_list, ofd);
+		ret = remove_files(G, target_path, cisf, swi, swicol, e, file_list, ofd);
 		if (ret < 0) {
 			/* internal error */
 			E_DEBUG("remove files: internal error");
