@@ -15,12 +15,12 @@ Library General Public License for more details.
 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.LIB.  If
 not, write to the Free Software Foundation, Inc., 675 Mass Ave,
-Cambridge, MA 02139, USA.  */
+Cambridge, MA 02110-1301, USA.  */
 
+#include "swuser_config.h"
 #include <errno.h>
 #include <ctype.h>
 
-#include "swuser_config.h"
 #include "fnmatch_u.h"
 
 
