@@ -254,7 +254,7 @@ swgpg_create(void)
 	SWGPG_VALIDATE * w = (SWGPG_VALIDATE *)malloc(sizeof(SWGPG_VALIDATE));
 	E_DEBUG("");
 	if (!w) return NULL;
-	w->gpg_prognameM = swlib_strdup("gpg");
+	w->gpg_prognameM = swlib_strdup(SWGPG_GPG_BIN);
 	w->list_of_sigsM = strar_open();
 	w->list_of_sig_namesM = strar_open();
 	w->list_of_status_blobsM = strar_open();
@@ -763,9 +763,9 @@ swgpg_get_package_signature_command(
 		strcasecmp(signer, "GPG2") == 0
 	) {
 		if (strcasecmp(signer, "GPG2") == 0) {
-			signerpath = shcmd_find_in_path(envpath, SIGNER_GPG2_BIN);
+			signerpath = shcmd_find_in_path(envpath, SWGPG_GPG2_BIN);
 		} else {
-			signerpath = shcmd_find_in_path(envpath, SIGNER_GPG_BIN);
+			signerpath = shcmd_find_in_path(envpath, SWGPG_GPG_BIN);
 		}
 		if (signerpath == NULL) return NULL;
 		shcmd_add_arg(sigcmd, signerpath);
@@ -795,7 +795,7 @@ swgpg_get_package_signature_command(
 	} else if (strcasecmp(signer, "PGP2.6") == 0) {
 		make_pgp_env(env, sizeof(env)/sizeof(char*));
 		shcmd_set_envp(sigcmd, env);
-		signerpath = shcmd_find_in_path(envpath, SIGNER_PGP26_BIN);
+		signerpath = shcmd_find_in_path(envpath, SWGPG_PGP26_BIN);
 		if (signerpath == NULL) return NULL;
 		shcmd_add_arg(sigcmd, signerpath);
 		if (gpg_name && strlen(gpg_name)) {
@@ -809,7 +809,7 @@ swgpg_get_package_signature_command(
 	} else if (strcasecmp(signer, "PGP5") == 0) {
 		make_pgp_env(env, sizeof(env)/sizeof(char*));
 		shcmd_set_envp(sigcmd, env);
-		signerpath = shcmd_find_in_path(envpath, SIGNER_PGP5_BIN);
+		signerpath = shcmd_find_in_path(envpath, SWGPG_PGP5_BIN);
 		if (signerpath == NULL) return NULL;
 		shcmd_add_arg(sigcmd, signerpath);
 		if (gpg_name && strlen(gpg_name)) {
@@ -1052,8 +1052,6 @@ swgpg_get_package_signature(
 	pid[2] = swfork((sigset_t*)(NULL));
 	if (pid[2] < 0) return (char *)NULL;
 	if (pid[2] == 0) {
-		int flags = 0;
-		XFORMAT * xformat;
 		close_passfd();
 		close(input[1]);
 		swlib_pipe_pump(filter[1], input[0]);
