@@ -190,6 +190,7 @@ get_object_by_swverid(SWHEADER * swheader, SWVERID * swverid,
 	 * step to first object
  	 */
 	next_line=swheader_get_current_line(swheader);
+	E_DEBUG2("initial next_line is %p", (void*)next_line);
 	if (!next_line)
 		return NULL;
 	while ( next_line && (swheaderline_get_type(next_line)
@@ -214,9 +215,12 @@ get_object_by_swverid(SWHEADER * swheader, SWVERID * swverid,
 			t_swverid = NULL;
 			swheader_set_current_offset_p_value(swheader,
 								object_offset);
-			if (nmatches) (*nmatches)++;
 			retval = next_line;
 			ret_object_offset = object_offset;
+			if (nmatches)
+				(*nmatches)++;
+			else
+				break;
 			E_DEBUG("");
 		}
 		if (t_swverid) swverid_close(t_swverid);
