@@ -68,6 +68,7 @@ static struct timespec * io_req = (struct timespec*)NULL;
 static int g_burst_adjust = 65000;
 
 #define TEE_DB_FILE "/tmp/synct_buf.bin"
+#define DO_TEE 1	/* this is for debugging */
 #define DO_TEE 0	/* this is for debugging */
 	
 static
@@ -99,6 +100,7 @@ synct_look_for_eof(SYNCT * synct, unsigned char ** p_trailer_start)
 	ibuf = synct->bufM;
 	pos = ibuf;
 
+	E_DEBUG("");
 	synct->mt_spanM++;
 	while (
 		(int)(pos - ibuf) < len &&
@@ -106,6 +108,7 @@ synct_look_for_eof(SYNCT * synct, unsigned char ** p_trailer_start)
 	) {
 		if (*pos && *pos == *(synct->mtpM)) {
 			/* so far so good */
+			E_DEBUG("so far so good");
 			if (*(synct->mtpM) == synct->mtM[0]) {
 				*p_trailer_start = pos;
 				synct->trailer_startM = (char*)pos;
@@ -114,10 +117,12 @@ synct_look_for_eof(SYNCT * synct, unsigned char ** p_trailer_start)
 			synct->mtpM++;
 		} else if (*pos == '\0') {
 			/* skip intervening NULs */
+			E_DEBUG("skipping NULs");
 			synct->mt_nullsM++;
 			;
 		} else {
 			/* reset, bad match */
+			E_DEBUG("reset, bad match");
 			synct->mt_spanM = 0;
 			synct->trailer_startM = NULL;
 			synct->mtpM = synct->mtM;
@@ -129,8 +134,10 @@ synct_look_for_eof(SYNCT * synct, unsigned char ** p_trailer_start)
 
 	if (*(synct->mtpM) == '\0') {
 		/* Found the trailer string */
+		E_DEBUG("found trailer");
 		return (char*)pos;
 	} else {
+		E_DEBUG("not found");
 		return NULL; /* not found */
 	}
 }
@@ -1610,7 +1617,7 @@ swlib_synct_read(SYNCT * synct, int fd, void * buf)
 			E_DEBUG("odd block, read again");
 			tmpret = synct_i_read(synct, fd, (char*)ibuf);
 			if (tmpret < 0) {
-				return -1;
+				return -101;
 			}
 			if (DO_TEE) swlib_tee_to_file(TEE_DB_FILE, -1, (char*)ibuf, SWLIB_SYNCT_BLOCKSIZE, 1);
 		}
@@ -1637,7 +1644,7 @@ swlib_synct_read(SYNCT * synct, int fd, void * buf)
 		E_DEBUG("reading");
 		ret = synct_i_read(synct, fd, (char*)ibuf);
 		if (ret < 0) {
-			return ret;
+			return 200 - ret;
 		}
 	 	if (DO_TEE) swlib_tee_to_file(TEE_DB_FILE, -1, (char*)ibuf, SWLIB_SYNCT_BLOCKSIZE, 1);
 		synct->firstM = 0;
@@ -1654,7 +1661,7 @@ swlib_synct_read(SYNCT * synct, int fd, void * buf)
 	E_DEBUG("");
 	if (ret <= 0) {
 		E_DEBUG2("ret=%d",ret);
-		return -1;
+		return -300;
 	}
 	if (DO_TEE) swlib_tee_to_file(TEE_DB_FILE, -1, (char*)tbuf, SWLIB_SYNCT_BLOCKSIZE, 1);
 
@@ -1662,14 +1669,15 @@ swlib_synct_read(SYNCT * synct, int fd, void * buf)
 
 	/* Now look for TRAILER!!! in the data */
 
-	rereads = 0;
-	provisional_trailer_start = NULL;
 	do {
+		rereads = 0;
+		provisional_trailer_start = NULL;
 		if (
 			(pos=synct_look_for_eof(synct, &provisional_trailer_start)) != NULL
 		) {
 			/* Found terminating string */
 
+			E_DEBUG("");
 			synct->doneM = 1;
 			synct->done_posM = (int)((char*)synct->trailer_startM - (char*)ibuf);
 			synct->remainsM = 0;
@@ -1684,9 +1692,10 @@ swlib_synct_read(SYNCT * synct, int fd, void * buf)
 			} else {
 				;
 			}
+			E_DEBUG("");
 			memcpy(buf, ibuf, ret);
 			break;
-		} if (provisional_trailer_start) {
+		} else if (provisional_trailer_start) {
 			/* Found part of terminating string, we must now determine what
 			   it really is by continuing to read */
 
@@ -1698,7 +1707,7 @@ swlib_synct_read(SYNCT * synct, int fd, void * buf)
 			rereads++;
 			ret = synct_i_read(synct, fd, (char*)((char*)tbuf+SWLIB_SYNCT_BLOCKSIZE));
 			if (ret <= 0) {
-				return -1;
+				return -400;
 			}
 		} else {
 			/* This code block handles the case when there is a false match
@@ -1708,19 +1717,23 @@ swlib_synct_read(SYNCT * synct, int fd, void * buf)
 			synct->doneM = 0;
 			if (rereads > 1) {
 				/* fatal, unhandled */
-				return -1;
+				E_DEBUG("");
+				return -404;
 			}
 			if (rereads == 0) {
+				E_DEBUG("");
 				ret = SWLIB_SYNCT_BLOCKSIZE;
 				memcpy(buf, ibuf, ret);
 			} else {
 				/* reread can only equal 1 here */
+				E_DEBUG("");
 				ret = SWLIB_SYNCT_BLOCKSIZE + (rereads * SWLIB_SYNCT_BLOCKSIZE);
 				memcpy(buf, ibuf, ret);
 				memcpy(ibuf, tbuf+SWLIB_SYNCT_BLOCKSIZE, SWLIB_SYNCT_BLOCKSIZE);
 			}
 			break;
 		}
+		E_DEBUG("");
 	} while (provisional_trailer_start != NULL);
 
 	E_DEBUG2("ret=%d", ret);
@@ -1749,7 +1762,7 @@ swlib_synct_suck(int ofd, int ifd)
 		}
 	} while (ret > 0);
 	swlib_synct_delete(synct);
-	if (ret < 0) return -1;
+	if (ret < 0) return ret;
 	return wtotal;
 }
 
@@ -2363,7 +2376,10 @@ swlib_pad_amount(int fd, int amount)
 			fd, nullblock, am);
 		
 		if (ret <= 0) {
-			SWLIB_INTERNAL("")
+			if (ret < 0)
+				fprintf(stderr, "%s: write error: %s\n", swlib_utilname_get(), strerror(errno));
+			else
+				SWLIB_INTERNAL("");
 			if (count <= 0) return -1;
 			return -count;
 		}
@@ -2779,7 +2795,7 @@ swlib_append_synct_eof(STROB * buf)
 		"printf \"" CPIO_INBAND_EOA_FILENAME "\\r\\n\"\n"
 		"printf \"\\r\\n\"\n"
 		") | dd 2>/dev/null\n"
-		") | dd obs=%d 2>/dev/null | dd ibs=%d obs=%d conv=sync 2>/dev/null\n",
-		SWLIB_SYNCT_BLOCKSIZE*3, SWLIB_SYNCT_BLOCKSIZE*2, SWLIB_SYNCT_BLOCKSIZE*2);
+		") | dd ibs=%d obs=%d 2>/dev/null | dd ibs=%d obs=%d conv=sync 2>/dev/null\n",
+		SWLIB_SYNCT_BLOCKSIZE*3, SWLIB_SYNCT_BLOCKSIZE*3, SWLIB_SYNCT_BLOCKSIZE*2, SWLIB_SYNCT_BLOCKSIZE*2);
 		/* Ending Subshell with sync'ing dd */
 }
