@@ -257,6 +257,7 @@ int 		swlib_audit_distribution(XFORMAT * xformat, int do_re_encode, int ofd, uin
 			int * deadman, void (*alarm_handler)(int));
 mode_t		swlib_apply_mode_umask(char type, mode_t umask, mode_t mode);
 int 		swlib_open_memfd(void);
+int 		swlib_close_memfd(int fd);
 int 		swlib_get_verbose_level(void);
 void 		swlib_set_verbose_level(int n);
 size_t		swlib__strlcpy(char * dst, const char * src, size_t siz);
@@ -305,4 +306,5 @@ void 		swlib_squash_illegal_tag_chars(char * s);
 intmax_t 	swlib_digs_copy(int ofd, int ifd, intmax_t count, FILE_DIGS * digs, int);
 void 		std_quicksort (void *const pbase, size_t total_elems, size_t size, int  (*)(const void *, const void *));
 mode_t		 swlib_filestring_to_mode(char * str, int do_include_type);
+void swlib_append_synct_eof(STROB * buf);
 #endif
