@@ -13,7 +13,7 @@ main (int argc, char ** argv ) {
    DEFER * defers=defer_open(arf);
    PORINODE * porinode=porinode_open();
    TARU * taru = taru_create();
-   return taru_process_copy_out(taru, STDIN_FILENO, STDOUT_FILENO, defers, porinode, arf);
+   return taru_process_copy_out(taru, STDIN_FILENO, STDOUT_FILENO, defers, porinode, arf, -1, -1, (intmax_t*)NULL, NULL);
 }
 
 
