@@ -144,16 +144,48 @@ shls_missing_which() {
 }
 
 shls_write_cat_ar() {
-	# Prefix: xxc
+	# Prefix: xxcy
 	PAXCMD="dd count=2 if=/dev/zero 2>/dev/null; shls_false_"
-	shls_missing_which pax 0</dev/null 1>/dev/null 2>/dev/null
-	xxc_ret=$?
-	case "$xxc_ret" in 0) PAXCMD="pax -b 512 -w"; ;; esac
 	shls_check_for_gnu_tar 0</dev/null
-	xxc_ret=$?
-	case "$xxc_ret" in 0) PAXCMD="tar  cf - -b1 --files-from=-"; ;; esac
-	$PAXCMD
-	return "$?"
+	xxcy_ret_tar=$?
+	xxcy_ret_pax=1
+	case "$xxcy_ret_tar" in
+		0) PAXCMD="tar  cf - -b1 --files-from=-";
+		$PAXCMD
+		return "$?"
+		;;
+		*)
+		shls_missing_which pax 0</dev/null 1>/dev/null 2>/dev/null
+		xxcy_ret_pax=$?
+		;;
+	esac
+
+	case "$xxcy_ret_pax" in
+		0) 
+		PAXCMD="pax -b 512 -w";
+		$PAXCMD
+		return "$?"
+		;;
+	esac
+	xxcy_list=""
+	xxcy_NAME=`
+	while IFS="" read -r file ; do
+		xxcy_list="$xxcy_list"" ""\"""$file""\""
+		echo "$xxcy_list"
+	done | tail -1`
+
+	tar 2>&1 0</dev/null | grep -i busybox 1>/dev/null
+	case $? in
+		0)
+		TARCMD="tar cf -"
+		;;
+		*)
+		TARCMD="tar cfb - 1"
+		;;
+	esac
+
+	eval $TARCMD $xxcy_NAME
+	return $?
 }
 
 shls_write_files_ar() {
@@ -180,9 +212,9 @@ shls_write_files_ar() {
 
 shls_get_verid_list() {
 	# Prefix: xxf
-	find . -type f -name 'INSTALLED' |
-	egrep -e '/[0-9]/INSTALLED' |
-	sed -e 's@INSTALLED@vendor_tag/qualifier/location@' |
+	find . -type f \( -name 'INSTALLED' -o -name '_INSTALLED' \) |
+	egrep -e '/[0-9]/INSTALLED' -e '/[0-9]/_INSTALLED' |
+	sed -e 's@INSTALLED@INSTALLED/Z_vendor_tag/Z_qualifier/Z_location@' |
 	egrep -v -e '^\.$' -e '^\./$' |
 	sed -e s@^./@@ |
         awk -- '
@@ -190,26 +222,25 @@ shls_get_verid_list() {
 	{
 		line=$0
 		path=$0
-		gsub(/\/vendor_tag\/qualifier\/location/, "", path)
+		gsub(/\/_*INSTALLED\/Z_vendor_tag\/Z_qualifier\/Z_location/, "", path)
 		contents=""
 		file=path "/vendor_tag"
 		getline contents <file
 		close(file);
-		gsub(/vendor_tag/, contents, line);
+		gsub(/Z_vendor_tag/, contents, line);
 		contents=""
 		file=path "/qualifier"
 		getline contents <file
 		close(file);
-		gsub(/qualifier/, contents, line);
+		gsub(/Z_qualifier/, contents, line);
 		contents=""
 		file=path "/location"
 		getline contents <file
 		close(file);
 		gsub(/^\//, "", contents);
-		gsub(/location/, contents, line);
-		# Output form:  '/' delimited
-		# bundle/product/revision/instance/vendor_tag/qualifier/location
-		#   1      2        3         4        5          6       7,8,...	
+		gsub(/Z_location/, contents, line);
+		# bundle/product/revision/instance/[_]INSTALLED/vendor_tag/qualifier/location
+		#   1      2        3         4        5          6           7        8...
 		print line
 	}
 	'
@@ -219,7 +250,7 @@ shls_get_vendor_tag_list2() {
 	# Prefix: xxf
 	find . -type f -name 'INSTALLED' |
 	egrep -e '/[0-9]/INSTALLED' |
-	sed -e 's@INSTALLED@vendor_tag@' |
+	sed -e 's@INSTALLED@INSTALLED/vendor_tag@' |
 	egrep -v -e '^\.$' -e '^\./$' |
 	sed -e s@^./@@ |
         awk -- '
@@ -263,6 +294,8 @@ shls_apply_socspec() {
 		ep_req_type=ENVIRON["SWBIS_REQ_TYPE"];
 		ep_cl_target_target=ENVIRON["SWBIS_CL_TARGET_TARGET"];
 		ep_swbis_util_name=ENVIRON["SWBIS_UTIL_NAME"];
+		ep_state=ENVIRON["SWBIS_STATE"];
+		ep_i_state="_IN"
 
 		bundle_match_indicator="."
 		product_match_indicator="."
@@ -286,12 +319,12 @@ shls_apply_socspec() {
 		}
 		printf("%-20s", C[2]);
 		printf("\tr=%-10s", C[3]);
-		if (length(C[5])) {
-			printf("\tv=%s", C[5]);
+		if (length(C[6])) {
+			printf("\tv=%s", C[6]);
 		}
 		printf("\ti=%-4s", C[4]);
-		if (length(C[6])) {
-			printf("\tq=%s", C[6]);
+		if (length(C[7])) {
+			printf("\tq=%s", C[7]);
 		}
 		if (length(locpath)) {
 			printf("\tl=%s", locpath);
@@ -366,8 +399,8 @@ shls_apply_socspec() {
 
 	{
 		# A line has the form
-		#    bundle/product/revision/instance/vendor_tag/qualifier/location
-		#      1      2        3         4        5          6       7,8,...	
+		#    bundle/product/revision/instance/[_]INSTALLED/vendor_tag/qualifier/location
+		#      1      2        3         4          5         6          7       8,9,...	
 		#	where
 		#	bundle: is the bundle tag, product tag if no bundle
 		# 	product: is the product tag
@@ -397,7 +430,7 @@ shls_apply_socspec() {
 		
 		# test the vendor tag
 		if ( got_match ~ /yes/ ) {
-			if ( C[5] !~ ep_vendor_tag ) {
+			if ( C[6] !~ ep_vendor_tag ) {
 				got_match="no"
 			}
 		}
@@ -460,10 +493,17 @@ shls_apply_socspec() {
 				got_match="no"
 			}
 		}
+
+		is_cat_corrupt="no"
+		if ( got_match ~ /yes/ ) {
+			if ( C[5] ~ ep_i_state ) {
+				is_cat_corrupt="yes"
+			}
+		}	
 		
 		# test the qualifier
 		if ( got_match ~ /yes/ ) {
-			if ( C[6] !~ ep_qualifier ) {
+			if ( C[7] !~ ep_qualifier ) {
 				got_match="no"
 			}
 		}
@@ -472,7 +512,7 @@ shls_apply_socspec() {
 		locpath=""
 		if ( got_match ~ /yes/ ) {
 			# make the location path
-			i=7
+			i=8
 			while (length(C[i]) > 0) {
 				locpath = locpath "/" C[i];
 				i++;
@@ -483,7 +523,7 @@ shls_apply_socspec() {
 			# dmsg(locpath)
 		}
 
-		if ( got_match == "yes" ) {
+		if ( got_match == "yes" && is_cat_corrupt == "no" ) {
 			number_of_matches++;
 			if (ep_list_form == "lform_dep1") {
 				printf("%s%s%s%s:%s:", response_prefix, bundle_match_indicator, product_match_indicator, fileset_match_indicator, C[1]);
@@ -495,6 +535,23 @@ shls_apply_socspec() {
 			} else {
 				print "internal error: invalid ep_list_form value" | "cat 1>&2"
 			}
+		} else if ( got_match == "yes" && is_cat_corrupt == "yes" ) {
+			if (ep_list_form == "lform_p1") {
+				printf("CORRUPT   ") | "cat 1>&2";
+				printf("%-20s", C[2]) | "cat 1>&2";
+				printf("\tr=%-10s", C[3]) | "cat 1>&2";
+				if (length(C[6])) {
+					printf("\tv=%s", C[6]) | "cat 1>&2";
+				}
+				printf("\ti=%-4s", C[4]) | "cat 1>&2";
+				if (length(C[7])) {
+					printf("\tq=%s", C[7]) | "cat 1>&2";
+				}
+				if (length(locpath)) {
+					printf("\tl=%s", locpath) | "cat 1>&2";
+				}
+				printf("\n") | "cat 1>&2";
+			}
 		}
 	}
 	END {
@@ -2108,7 +2165,7 @@ shls__cleansh() {
 	(
 		# ps -axw should work on GNU/Linux and BSD hosts
 		# ps -elf will be used on OpenSolaris
-		ps -axw || ps -elf
+		ps -axw 2>/dev/null || ps -elf
 	) | awk -- '
 	BEGIN {
 		FS=" ";
