@@ -1565,8 +1565,9 @@ swi_make_file_list(SWI * swi, SWUTS * swuts, char * location, int disallow_incom
 	}
 
 	if (n_compat  <= 0) {
-		SWLIB_INTERNAL("no compatible product found in entry");
-		return NULL;
+		/* SWLIB_INTERNAL("no compatible product found in entry"); */
+		SWLIB_WARN("no compatible product found in entry");
+		;
 	} else if (n_compat  > 1) {
 		SWLIB_WARN("more than one compatible product found");
 		;
