@@ -173,21 +173,24 @@ swi_file_member_create(void)
 void
 swi_control_script_delete(SWI_CONTROL_SCRIPT * s)
 {
-	if (s->baseM.tagM) free(s->baseM.tagM);
-	swi_file_member_delete(s->afileM);
+	if (s->baseM.b_tagM) free(s->baseM.b_tagM);
+	if (s->afileM)
+		swi_file_member_delete(s->afileM);
 	free(s);
 }
 
 SWI_CONTROL_SCRIPT *
 swi_control_script_create(void)
 {
+	static int id = 0;
+
 	SWI_CONTROL_SCRIPT * s;
 	SWSWI_E_DEBUG("");
 	s = (SWI_CONTROL_SCRIPT *)malloc(sizeof(SWI_CONTROL_SCRIPT));
 	swi_com_assert_pointer((void*)s, __FILE__, __LINE__);
 
 	swi_vbase_init(s, SWI_I_TYPE_SCRIPT, NULL, NULL);
-
+	s->sidM = ++id;
 	s->afileM = NULL; /* swi_file_member_create(); */
 	s->resultM = SWI_RESULT_UNDEFINED;
 	return s;
@@ -201,18 +204,39 @@ swi_add_script(SWI_SCRIPTS * thisisit, SWI_CONTROL_SCRIPT * v)
 	SWSWI_E_DEBUG("LEAVING");
 }
 
+int
+swi_control_script_get_return_code(char * posix_result)
+{
+	if (strcasecmp(posix_result, SW_RESULT_NONE) == 0) {
+		return SWI_RESULT_UNDEFINED ;
+	} else if (strcasecmp(posix_result, SW_RESULT_SUCCESS) == 0) {
+		return SWI_RESULT_SUCCESS;
+	} else if (strcasecmp(posix_result, SW_RESULT_WARNING) == 0) {
+		return SWI_RESULT_WARNING;
+	} else if (strcasecmp(posix_result, SW_RESULT_FAILURE) == 0) {
+		return SWI_RESULT_FAILURE;
+	} else {
+		/* internal error */
+		fprintf(stderr, "%s: unrecognized  POSIX result string: [%s]\n", swlib_utilname_get(), posix_result); 
+		return SWI_RESULT_FAILURE;
+	}
+}
+
 char *
 swi_control_script_posix_result(SWI_CONTROL_SCRIPT * s)
 {
-	if (s->resultM == SWI_RESULT_UNDEFINED) {
+	if (s->resultM == SWI_RESULT_UNDEFINED || s->resultM < 0) {
 		return SW_RESULT_NONE;
-	} else if (s->resultM == 0) {
+	} else if (s->resultM == SW_SUCCESS) {
 		return SW_RESULT_SUCCESS;
-	} else if (s->resultM == 1) {
+	} else if (s->resultM == SW_ERROR) {
 		return SW_RESULT_FAILURE;
-	} else if (s->resultM == 2) {
+	} else if (s->resultM == SW_WARNING) {
+		return SW_RESULT_WARNING;
+	} else if (s->resultM == SW_NOTE) {
 		return SW_RESULT_WARNING;
 	} else {
+		fprintf(stderr, "%s: internal error: bad result code: [%d]\n", swlib_utilname_get(), s->resultM); 
 		return SW_RESULT_FAILURE;
 	}
 }
@@ -251,7 +275,7 @@ swi_afile_write_script_cases(SWI_SCRIPTS * scripts, STROB * buf)
 			/*
 			 * Mark the tag as being used
 			 */
-			set_is_ieee_control_script(control_script->baseM.tagM, 1);
+			set_is_ieee_control_script(control_script->baseM.b_tagM, 1);
 
 			/*
 			 * Now write the shell case statement fragment
@@ -265,11 +289,18 @@ swi_afile_write_script_cases(SWI_SCRIPTS * scripts, STROB * buf)
 			strob_sprintf(buf, STROB_DO_APPEND,
 				"\t\t%s)\n"
 				"\t\t\texport SW_CONTROL_TAG=\"%s\"\n"
-				"\t\t\texport SW_CONTROL_DIRECTORY=\"${SW_ROOT_DIRECTORY}/${SW_CATALOG}/${SWBIS_CATALOG_ENTRY}/%s/%s\"\n"
+				"\t\tcase \"$SW_CATALOG\" in\n"
+				"\t\t\t/*) export SW_CONTROL_DIRECTORY=\"${SW_CATALOG}/${SWBIS_CATALOG_ENTRY}/%s/%s\"\n"
+				"\t\t\t;;\n"
+				"\t\t\t*) export SW_CONTROL_DIRECTORY=\"${SW_ROOT_DIRECTORY}/${SW_CATALOG}/${SWBIS_CATALOG_ENTRY}/%s/%s\"\n"
+				"\t\t\t;;\n"
+				"\t\tesac\n"
 				"\t\t\tSWBCS_SCRIPT_NAME=\"%s\"\n"
 				"\t\t\t;;\n",
-				control_script->baseM.tagM,
-				control_script->baseM.tagM,
+				control_script->baseM.b_tagM,
+				control_script->baseM.b_tagM,
+				SWINSTALL_INCAT_NAME,
+				control_script->afileM->pathnameM,
 				SWINSTALL_INCAT_NAME,
 				control_script->afileM->pathnameM,
 				name
@@ -310,14 +341,6 @@ swi_afile_write_script_cases(SWI_SCRIPTS * scripts, STROB * buf)
 	return 0;
 }
 
-/*
-char **
-swi_afile_ieee_control_script_list(void)
-{
-	return gs_control_scripts;
-}
-*/
-
 int
 swi_afile_is_ieee_control_script(char * pathname)
 {
