@@ -102,8 +102,9 @@ etar_emit_data_from_fd(ETAR * etar, int ofd, int ifd)
 			swlib_utilname_get(), ret);
 		return -1;
 	}
-	if (ret) {
-		remains = TARRECORDSIZE - (ret % TARRECORDSIZE);
+	remains = ret % TARRECORDSIZE;
+	if (ret && remains > 0) {
+		remains = TARRECORDSIZE - remains;
 		ret1 = swlib_pad_amount(ofd, remains);
 		if (ret1 < 0) {
 			fprintf(stderr, "%s: etar_emit_data_from_fd(): loc=2: ret = %d\n",
@@ -128,9 +129,11 @@ etar_emit_data_from_buffer(ETAR * etar, int ofd, char * buf, int bufsize)
 	else
 		len = bufsize;
 	ret = atomicio(uxfio_write, ofd, (void*)buf, len);
-	if (ret != len) return -1;
-	if (ret) {
-		remains = TARRECORDSIZE - (ret % TARRECORDSIZE);
+	if (ret < 0) return ret;
+	if (ret != len) return -2;
+	remains = ret % TARRECORDSIZE;
+	if (ret && remains > 0) {
+		remains = TARRECORDSIZE - remains;
 		ret1 = swlib_pad_amount(ofd, remains);
 		if (ret1 < 0) return -2;
 	} else {
