@@ -6,7 +6,7 @@
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -16,7 +16,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #include "swuser_config.h"
 #include <stdio.h>
@@ -242,12 +242,14 @@ taru_filehdr2statbuf(struct stat *statbuf, struct new_cpio_header *file_hdr)
 	statbuf->st_nlink = (nlink_t) (file_hdr->c_nlink);
 	statbuf->st_uid = (uid_t) (file_hdr->c_uid);
 	statbuf->st_gid = (gid_t) (file_hdr->c_gid);
-	statbuf->st_size = (off_t) (file_hdr->c_filesize);
+
+	statbuf->st_size = (off_t)taru_hdr_get_filesize(file_hdr);
+
 	statbuf->st_atime = (time_t) (tim);
 	statbuf->st_ctime = (time_t) (tim);
 	statbuf->st_mtime = (time_t) (file_hdr->c_mtime);
 	statbuf->st_blksize = (long) (512);
-	statbuf->st_blocks = (long) ((int) (statbuf->st_size) / 512 + 1);
+	statbuf->st_blocks = (long) ((statbuf->st_size) / 512 + 1);
 
 	if (file_hdr->c_cu == TARU_C_BY_UNAME) {
 		if (taru_get_gid_by_name(ahsStaticGetTarGroupname(file_hdr),
@@ -329,6 +331,10 @@ taru_statbuf2filehdr (struct new_cpio_header *file_hdr,
 	else if (S_ISFIFO(statbuf->st_mode))
 		file_hdr->c_mode |= CP_IFIFO;
 #endif
+#ifdef S_ISDOOR
+	else if (S_ISDOOR(statbuf->st_mode))
+		file_hdr->c_mode |= CP_IFDOOR;
+#endif
 #ifdef S_ISLNK
 	else if (S_ISLNK(statbuf->st_mode))
 		file_hdr->c_mode |= CP_IFLNK;
@@ -347,7 +353,7 @@ taru_statbuf2filehdr (struct new_cpio_header *file_hdr,
 	file_hdr->c_nlink = statbuf->st_nlink;
 	file_hdr->c_uid = statbuf->st_uid;
 	file_hdr->c_gid = statbuf->st_gid;
-	file_hdr->c_filesize = statbuf->st_size;
+	file_hdr->c_filesize = (uintmax_t)(statbuf->st_size);
 	file_hdr->c_mtime = statbuf->st_mtime;
 	file_hdr->c_dev_maj = major(statbuf->st_dev);
 	file_hdr->c_dev_min = minor(statbuf->st_dev);
