@@ -4,7 +4,8 @@
 #include <stdlib.h>
 #include <string>
 #include <typeinfo>
-#include "stream_config.h"
+
+#include "xstream_config.h"
 #include "swdeffile.h"
 #include "swparser.h"
 #include "swpathname.h"
