@@ -6,7 +6,7 @@
 #include <unistd.h>
 #include <sys/stat.h>
 #include <errno.h>
-#include "stream_config.h"
+#include "xstream_config.h"
 #include "swparser.h"
 #include "swpsf.h"
 #include "swdefinitionfile.h"
